// Electron Related Constants
const {app, protocol, BrowserWindow} = require('electron');
const url = require('url');
const path = require('path');

// Global reference of window object to prevent GC from killing it.
let mainWindow;

function createWindow () {
  // Create the browser window.
  mainWindow = new BrowserWindow({width: 800, height: 600, title: "NanoWallet", show: false, webPreferences: { nodeIntegration: false }});

  // Load the identification page.
  mainWindow.loadURL(url.format({
    pathname: path.join(__dirname, './src/start.html'),
    protocol: 'file:',
    slashes: true
  }));

  mainWindow.on("ready-to-show", function() {
    mainWindow.show();
  })

  // For Debug
  // mainWindow.webContents.openDevTools()

  // Close the window.
  mainWindow.on('closed', function () {
    mainWindow = null;
  });

  return mainWindow;
}

// Open the window.
app.on('ready', createWindow);

// Quit when all windows are closed.
app.on('window-all-closed', function () {
  // Different behavior for OSX.
  if (process.platform !== 'darwin') {
    app.quit()
  }
});

app.on('activate', function () {
  // On OS X it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (mainWindow === null) {
    createWindow()
  }
});

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.